from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ptuevents', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='PTUsers',
            old_name='ad_guid',
            new_name='ad_sid',
        ),

        migrations.RenameField(
            model_name='PTWorkstations',
            old_name='ad_guid',
            new_name='ad_sid',
        ),

        migrations.AlterField(
            model_name='PTUsers',
            name='name',
            field=models.CharField(max_length=250),
        ),

        migrations.AddField(
            model_name='PTWorkstations',
            name='location',
            field=models.CharField(max_length=100, blank=True),
        ),

        migrations.RemoveField(
            model_name='PTUsers',
            name='comments',
        ),
    ]



from .serializers import PTAppSystemSerializer, PTAppSystemAssignmentSerializer
from netbox.api.viewsets import NetBoxModelViewSet
from ..models import PTUEventRelation, PTUEvent, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations, PTWorkstationsAssignment
from .serializers import PTUEventRelationSerializer, PTUEventSerializer, PTUEventAssignmentSerializer, PTUsersSerializer, PTWorkstationsSerializer, PTWorkstationsAssignmentSerializer
from .. import filtersets


class PTUEventListViewSet(NetBoxModelViewSet):
    queryset = PTUEvent.objects.prefetch_related('tags')
    serializer_class = PTUEventSerializer
    filterset_class = filtersets.PTUEventFilterSet


class PTUEventRelationListViewSet(NetBoxModelViewSet):
    queryset = PTUEventRelation.objects.prefetch_related('tags')
    serializer_class = PTUEventRelationSerializer
    filterset_class = filtersets.PTUEventRelationFilterSet


class PTUEventAssignmentViewSet(NetBoxModelViewSet):
    queryset = PTUEventAssignment.objects.prefetch_related(
        'object', 'ptuevent', 'relation')
    serializer_class = PTUEventAssignmentSerializer
    filterset_class = filtersets.PTUEventAssignmentFilterSet


class PTAppSystemViewSet(NetBoxModelViewSet):
    queryset = PTAppSystem.objects.prefetch_related('tenant', 'tags')
    serializer_class = PTAppSystemSerializer
    filterset_class = filtersets.PTAppSystemFilterSet


class PTAppSystemAssignmentViewSet(NetBoxModelViewSet):
    queryset = PTAppSystemAssignment.objects.prefetch_related(
        'object', 'app_system')
    serializer_class = PTAppSystemAssignmentSerializer
    filterset_class = filtersets.PTAppSystemAssignmentFilterSet


class PTUsersListViewSet(NetBoxModelViewSet):
    queryset = PTUsers.objects.prefetch_related('tags')
    serializer_class = PTUsersSerializer
    filterset_class = filtersets.PTUsersFilterSet


class PTWorkstationsListViewSet(NetBoxModelViewSet):
    queryset = PTWorkstations.objects.prefetch_related('tags')
    serializer_class = PTWorkstationsSerializer
    filterset_class = filtersets.PTWorkstationsFilterSet


class PTWorkstationsAssignmentViewSet(NetBoxModelViewSet):
    queryset = PTWorkstationsAssignment.objects.prefetch_related(
        'object', 'pt_workstations')
    serializer_class = PTWorkstationsAssignmentSerializer
    filterset_class = filtersets.PTWorkstationsAssignmentFilterSet




import strawberry_django
from .filtersets import PTUEventAssignmentFilterSet, PTAppSystemAssignmentFilterSet
from .models import PTUEventAssignment, PTAppSystemAssignment

from netbox.graphql.filter_mixins import autotype_decorator, BaseFilterMixin

__all__ = (
    'PTUEventAssignmentFilter',
    'PTAppSystemAssignmentFilter',
)


@strawberry_django.filter(PTUEventAssignment, lookups=True)
@autotype_decorator(PTUEventAssignmentFilterSet)
class PTUEventAssignmentFilter(BaseFilterMixin):
    pass


@strawberry_django.filter(PTAppSystemAssignment, lookups=True)
@autotype_decorator(PTAppSystemAssignmentFilterSet)
class PTAppSystemAssignmentFilter(BaseFilterMixin):
    pass


# Generated by Django 5.0.9 on 2024-10-21 14:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('ptuevents', '0003_alter_ptappsystem_custom_field_data_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ptappsystemassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.RenameField(
            model_name='ptueventassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.RenameField(
            model_name='ptworkstationsassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.AlterUniqueTogether(
            name='ptappsystemassignment',
            unique_together={('object_type', 'object_id', 'app_system')},
        ),
        migrations.AlterUniqueTogether(
            name='ptueventassignment',
            unique_together={('object_type', 'object_id', 'ptuevent', 'relation')},
        ),
        migrations.AlterUniqueTogether(
            name='ptworkstationsassignment',
            unique_together={('object_type', 'object_id', 'pt_workstations')},
        ),
    ]



from typing import Annotated, List

import strawberry
import strawberry_django
from .filters import PTUEventAssignmentFilter, PTAppSystemAssignmentFilter
from .models import PTUEvent, PTUEventRelation, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment

from django.contrib.contenttypes.models import ContentType
from tenancy.models import Tenant


# PTContentTypeType (для ContentType, используемое в GenericForeignKey)
@strawberry_django.type(
    model=ContentType,
    fields="__all__",
)
class PTContentTypeType:
    pass

# PTTenantType (необходим для использования в PTAppSystemType)
@strawberry_django.type(
    model=Tenant,
    fields="__all__",
)
class PTTenantType:
    pass


# PTUEventType
@strawberry_django.type(
    model=PTUEvent,
    fields="__all__",
)
class PTUEventType:
    pass


# PTUEventRelationType
@strawberry_django.type(
    model=PTUEventRelation,
    fields="__all__",
)
class PTUEventRelationType:
    pass


# PTUEventAssignmentType с GenericForeignKey и внешними ключами
@strawberry_django.type(
    model=PTUEventAssignment,
    fields="__all__",
    filters=PTUEventAssignmentFilter,
)
class PTUEventAssignmentType:
    ptuevent: Annotated["PTUEventType", strawberry_django.field()]  # Внешний ключ на PTUEvent
    relation: Annotated["PTUEventRelationType", strawberry_django.field()]  # Внешний ключ на PTUEventRelation
    object_type: Annotated["PTContentTypeType", strawberry_django.field()]  # Внешний ключ на ContentType
    object: Annotated[str, strawberry_django.field()]  # Поле GenericForeignKey возвращается как строка или можно добавить логику


# PTAppSystemType с использованием PTTenantType
@strawberry_django.type(
    model=PTAppSystem,
    fields="__all__",
)
class PTAppSystemType:
    tenant: Annotated["PTTenantType", strawberry_django.field()]  # Внешний ключ на Tenant


# PTAppSystemAssignmentType с GenericForeignKey и внешними ключами
@strawberry_django.type(
    model=PTAppSystemAssignment,
    fields="__all__",
    filters=PTAppSystemAssignmentFilter,
)
class PTAppSystemAssignmentType:
    object_type: Annotated["PTContentTypeType", strawberry_django.field()]  # Внешний ключ на ContentType
    object: Annotated[str, strawberry_django.field()]  # Поле GenericForeignKey возвращается как строка или можно добавить логику
    app_system: Annotated["PTAppSystemType", strawberry_django.field()]  # Внешний ключ на PTAppSystem




@strawberry.type
class Query:
    # Получение одного PTUEvent по ID
    @strawberry.field
    def ptuevent(self, id: int) -> PTUEventType:
        return PTUEvent.objects.get(pk=id)

    # Получение списка PTUEvent
    ptuevent_list: List[PTUEventType] = strawberry_django.field()

    # Получение одного PTUEventRelation по ID
    @strawberry.field
    def relation(self, id: int) -> PTUEventRelationType:
        return PTUEventRelation.objects.get(pk=id)

    # Получение списка PTUEventRelation
    relation_list: List[PTUEventRelationType] = strawberry_django.field()

    # Получение одного PTUEventAssignment по ID
    @strawberry.field
    def ptuevent_assignment(self, id: int) -> PTUEventAssignmentType:
        return PTUEventAssignment.objects.get(pk=id)

    # Получение списка PTUEventAssignment
    ptuevent_assignment_list: List[PTUEventAssignmentType] = strawberry_django.field()

    # Получение одного PTAppSystem по ID
    @strawberry.field
    def ptapp_system(self, id: int) -> PTAppSystemType:
        return PTAppSystem.objects.get(pk=id)

    # Получение списка PTAppSystem
    ptapp_system_list: List[PTAppSystemType] = strawberry_django.field()

    # Получение одного PTAppSystemAssignment по ID
    @strawberry.field
    def ptapp_system_assignment(self, id: int) -> PTAppSystemAssignmentType:
        return PTAppSystemAssignment.objects.get(pk=id)

    # Получение списка PTAppSystemAssignment
    ptapp_system_assignment_list: List[PTAppSystemAssignmentType] = strawberry_django.field()


# Создание схемы
schema = [Query]


# Generated by Django 4.2.7 on 2024-10-17 10:48

from django.db import migrations, models
import utilities.json


class Migration(migrations.Migration):

    dependencies = [
        ('ptuevents', '0002_add_sid_location'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ptappsystem',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptuevent',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptueventrelation',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptusers',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptusers',
            name='status',
            field=models.CharField(default='enabled', max_length=250),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='ad_description',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='description',
            field=models.CharField(blank=True, max_length=500),
        ),
    ]



from netbox.search import SearchIndex, register_search
from . import models


@register_search
class PTUsersIndex(SearchIndex):
    model = models.PTUsers
    fields = (
        ('sAMAccountName', 100),
        ('vpnIPaddress', 300),
        ('firstname', 500),
        ('lastname', 500),
        ('ad_description', 500),
        ('description', 500),
        ('comment', 5000),
    )


@register_search
class PTWorkstationsIndex(SearchIndex):
    model = models.PTWorkstations
    fields = (
        ('name', 100),
        ('ad_description', 500),
        ('description', 500),
    )


indexes = [PTUsersIndex, PTWorkstationsIndex]
